@@ -5,18 +5,20 @@
 package utils
 
 import (
+	"strings"
+
 	"github.com/rs/zerolog/log"
+
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/base"
 	"github.com/zricethezav/gitleaks/v8/config"
 	"github.com/zricethezav/gitleaks/v8/detect"
-	"strings"
 )
 
 func Validate(rule config.Rule, truePositives []string, falsePositives []string) *config.Rule {
 	r := &rule
 	d := createSingleRuleDetector(r)
 	for _, tp := range truePositives {
-		if len(d.DetectString(tp)) != 1 {
+		if len(d.DetectString(tp)) < 1 {
 			log.Fatal().
 				Str("rule", r.RuleID).
 				Str("value", tp).
@@ -25,7 +27,8 @@ func Validate(rule config.Rule, truePositives []string, falsePositives []string)
 		}
 	}
 	for _, fp := range falsePositives {
-		if len(d.DetectString(fp)) != 0 {
+		findings := d.DetectString(fp)
+		if len(findings) != 0 {
 			log.Fatal().
 				Str("rule", r.RuleID).
 				Str("value", fp).
